@@ -50,13 +50,12 @@ class ROSSPkg():
         self.phreeqc_mod = phreeqc_mod
         self.parameters['os'] =  operating_system
         
-    def define_general(self, phreeqc_path, database_selection, simulation = 'scaling', domain = 'single', domain_phase = None, quantity_of_modules = 1, simulation_type = 'transport', simulation_title = None):
+    def define_general(self, database_selection, simulation = 'scaling', domain = 'single', domain_phase = None, quantity_of_modules = 1, simulation_type = 'transport', simulation_title = None):
         '''Establish general conditions'''
         self.parameters['water_mw'] = float(get_compounds('water', 'name')[0].molecular_weight)
         self.parameters['water_grams_per_liter'] = water_density()
         
         # parameterize the input file
-        self.parameters['phreeqc_path'] = phreeqc_path
         self.parameters['simulation_type'] = simulation_type
         self.parameters['simulation'] = simulation
         self.parameters['quantity_of_modules'] = quantity_of_modules
@@ -632,7 +631,7 @@ class ROSSPkg():
 
     def execute(self, simulated_to_real_time = 9.29):
         '''Execute a PHREEQC input file '''
-        database_path = os.path.join(self.parameters['phreeqc_path'], 'database\\{}.dat'.format(self.parameters['database_selection']))
+        database_path = os.path.join(self.parameters['root_path'], 'databases','{}.dat'.format(self.parameters['database_selection']))
 
         def run(input_file, first=False):
             phreeqc = self.phreeqc_mod.IPhreeqc()                 
@@ -641,7 +640,6 @@ class ROSSPkg():
             
             # define the conc dictionary
             output = phreeqc.get_selected_output_array()
-
             header = output[0]
             conc = {}
             for head in header:
@@ -1118,16 +1116,13 @@ class ROSSPkg():
                 file_number += 1
             figure.savefig('{}_{}.{}'.format(figure_path, file_number, export_format))
 
-    def input_file(self, operating_system, phreeqc_path, database_selection, simulation_type, simulation_title, water_selection, quantity_of_modules = 1, module_characteristics = {}, simulation = 'scaling', domain = 'dual', permeate_approach = 'linear permeate', permeate_efficiency = 1, head_loss = -0.15, final_cf = 2, custom_water_parameters = {}, ignored_minerals = [], existing_parameters = {}, export_figure = True):
-        """Concisely create an input file of the software """
-        self.define_general(operating_system, phreeqc_path, database_selection, simulation_type, simulation_title)
-        self.transport(module_characteristics = module_characteristics, quantity_of_modules = quantity_of_modules, domain = domain, simulation = simulation)
-        self.reaction(permeate_approach = permeate_approach, permeate_efficiency = permeate_efficiency, head_loss = head_loss, final_cf = final_cf)
-        self.solutions(water_selection = water_selection, custom_water_parameters = custom_water_parameters)
-        self.equilibrium_phases(ignored_minerals = ignored_minerals, existing_parameters = existing_parameters)
+    def test(self):
+        self.define_general(database_selection = 'pitzer')
+        self.transport(simulation_time = 200)
+        self.reaction()
+        self.solutions(water_selection = 'red_sea')
+        self.equilibrium_phases()
         self.selected_output()
         self.export()
-        
-    def complete_simulation():
         self.execute()
-        self.process_selected_output(export_figure = export_figure)
\ No newline at end of file
+        self.process_selected_output()
\ No newline at end of file
